@@ -6,6 +6,7 @@ import re
 
 import base64
 from io import BytesIO
+from telegram.poll import PollAnswer
 import yaml
 
 import logging
@@ -14,7 +15,7 @@ from configparser import ConfigParser
 config = ConfigParser()
 config.read('config.ini')
 
-logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s', filename=config["log"]["logfile"],
+logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
                     level=logging.INFO)
 
 logger = logging.getLogger(__name__)
@@ -96,9 +97,12 @@ class Action():
                 if "parse_mode" in item:
                     parse_mode = item["parse_mode"]
 
-                if type(update) != CallbackQuery and update.poll_answer:
-                    update.poll_answer.user.send_message(item["text"].format(
+                if type(update) == CallbackQuery:
+                    update.from_user.send_message(item["text"].format(
                         **{"echo": update.message.text, "name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
+                elif update.poll_answer:
+                    update.poll_answer.user.send_message(item["text"].format(
+                        **{"name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
                 else:
                     update.message.reply_text(item["text"].format(
                         **{"echo": update.message.text, "name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
@@ -162,4 +166,5 @@ class Action():
                     if query.data == case["condition"]:
                         return Action(case["action"])(query, context)
             elif item["type"] == "function":
-                self.action_functions[item["func"]](update, context)
+                arguments = {i:item[i] for i in item if i!='type' and i!='func'}
+                self.action_functions[item["func"]](update, context, **arguments)
